# This package buildrequires flit_core to build the wheel, but flit_core requires tomli.
# To bootstrap, we copy the files to appropriate locations manually and create a minimal dist-info metadata.
# Note that as a pure Python package, the wheel contains no pre-built binary stuff.
# When bootstrap is enabled, we don't run tests either, just an import check.
%bcond_with bootstrap

%global pypi_name tomli

Name:           python-%{pypi_name}
Version:        2.0.1
Release:        %mkrel 1
Summary:        A little TOML parser for Python
License:        MIT
Group:          Development/Python
URL:            https://pypi.org/project/tomli/
Source0:        %{pypi_source}
BuildArch:      noarch
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
%if ! %{with bootstrap}
BuildRequires:  python3-flit-core
%endif

%description
Tomli is a Python library for parsing TOML and is fully compatible with TOML
v1.0.0.

%package -n python3-tomli
Summary:          A little TOML parser for Python
Group:            Development/Python

%description -n python3-tomli
Tomli is a Python library for parsing TOML and is fully compatible with TOML
v1.0.0.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%if ! %{with bootstrap}
%generate_buildrequires
%pyproject_buildrequires -r
%endif

%build
%if ! %{with bootstrap}
%pyproject_wheel
%else
%global distinfo tomli-%{version}+rpmbootstrap.dist-info
mkdir %{distinfo}
cat > %{distinfo}/METADATA << EOF
Metadata-Version: 2.2
Name: tomli
Version: %{version}+rpmbootstrap
EOF
%endif

%install
%if ! %{with bootstrap}
%pyproject_install
%pyproject_save_files %{pypi_name}
%else
mkdir -p %{buildroot}%{python3_sitelib}
cp -a src/tomli %{distinfo} %{buildroot}%{python3_sitelib}
echo '%{python3_sitelib}/tomli/' > %{pyproject_files}
echo '%{python3_sitelib}/%{distinfo}/' >> %{pyproject_files}
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc README.md
%license LICENSE


%changelog
* Thu Aug 11 2022 wally <wally> 2.0.1-1.mga8
+ Revision: 1876922
- disable bootstrap build mode

* Thu Aug 11 2022 wally <wally> 2.0.1-0.mga8
+ Revision: 1876910
- bootstrap build for mga8
- sync with cauldron (mga#30736)
- add bcond for bootstrapping (originally from Fedora)

* Sun Apr 10 2022 wally <wally> 2.0.1-1.mga9
+ Revision: 1848629
- new version 2.0.1

* Tue Mar 29 2022 umeabot <umeabot> 2.0.0-2.mga9
+ Revision: 1832563
- Mageia 9 Mass Rebuild

* Sun Feb 06 2022 wally <wally> 2.0.0-1.mga9
+ Revision: 1771914
- new version 2.0.0
- rebuild for python 3.10

* Fri Sep 03 2021 wally <wally> 1.2.1-1.mga9
+ Revision: 1744227
- imported package python-tomli

